@@ -36,7 +36,7 @@ def ip_addy_changed(external_ip, prev_ext_ip):
 
 def touch_ddns_server(url):
     log.debug("touching url: {}".format(url))
-    resp = urllib.request.urlopen(url).read
+    resp = urllib.request.urlopen(url).read()
     log.debug("Response:\n{}".format(resp))
 
 def save_ip_addy(ip):
